
use BDDPanel4, replace

gen TOThours = alhrp28wi + alhrp28hu
gen TOTearn  = incomewi  + incomehu
gen lnTOThours = ln(TOThours)
gen lnTOTearn = ln(TOTearn)


* indicates whether women has more or less than 40% of income in first observation
so  familyidnum year 
by familyidnum : gen first = (_n==1)
replace first = . if familyidnum == .
replace first = . if personidhu == "" | personidwi == "" 
gen firstincwi = incomewi if first == 1
gen firstinchu = incomehu if first == 1
recode firstincwi firstinchu (.=0)
bys familyidnum : egen firstincwi2 = sum(firstincwi)
bys familyidnum : egen firstinchu2 = sum(firstinchu)
replace firstinchu2 = . if personidhu ==""
replace firstincwi2 = . if personidwi ==""

gen Type_LH_inc4 = ( firstincwi2  <= 0.4*(firstincwi2 + firstinchu2) ) if firstincwi2  != . &  firstinchu2 != .
gen Type_HL_inc4 = ( firstincwi2  > 0.4*(firstincwi2 + firstinchu2) ) if firstincwi2  != . &  firstinchu2 != .

drop first firstincwi firstinchu firstinchu2 firstincwi2


global weight   "[aw=poids_couple]"
gen miss_outcome  = missing(hourswi,incomewi,hourshu,incomehu,wifeshareinc,wifesharehour)


*********************** TABLE 7 ***********************

global treatment_cilw "reg_cilw regeg_cilw"
global treatment  "reg_cilw_bef1 reg_cilw_noncaught regeg_cilw_bef1 regeg_cilw_noncaught "

global spe     "has_child  d_1y -d_10y  y_1994-y_2011"
global spe2    "has_child  d_1y -d_10y  y_1994-y_2011 d_1y_c -d_10y_c y_1994_c -y_2011_c prov_TN_child-prov_CB_child "

global sample "(cohab==1) & duree_couple <=10 & allage == 1 & miss_outcome == 0  & migrant_prov_fam ==0"


**** PROGRAM ********
capture program drop res_couples_tab7
program res_couples_tab7
args subsample name_subsample c cluster

cap log close  _all
log using "$results\tab7_couples `{'`name_subsample'`}' - cluster = `{'`cluster'`}'", replace text
log close  _all

preserve 
keep if `subsample'

foreach v in lnhourswi lnincomewi lnhourshu lnincomehu wifeshareinc wifesharehour lnTOTearn lnTOThours {

di "`v'"
capture est store clear 
	reghdfe `v' reg_cilw regeg_cilw $spe2 $weight if `subsample', absorb(familyidnum) vce(cluster `cluster')
	est store C`v'
	test  _b[reg_cilw]+_b[regeg_cilw] = 0
	scalar B`v' = _b[reg_cilw]+_b[regeg_cilw]
	scalar F`v' = r(F)
	scalar P`v' = r(p)
	boottest {reg_cilw} {regeg_cilw} {reg_cilw+regeg_cilw=0}, nograph reps(9999) weight(webb) cluster(`cluster')
	matrix CI_1 = r(CI_1)
	matrix CI_2 = r(CI_2)
	matrix M`v' = (r(t_1) \ r(p_1) \ CI_1[1,1] \ CI_1[1,2] \ r(t_2) \ r(p_2) \ CI_2[1,1] \ CI_2[1,2] \ B`v' \ F`v' \ P`v' \ r(t_3) \ r(p_3) \ r(F_3) )
	
	edfreg `v' reg_cilw regeg_cilw $spe2 $weight if `subsample', absorb(familyidnum) cluster(`cluster') select( reg_cilw regeg_cilw )
	matrix E`v' = e(edf)	
}

restore
	matrix wild = Mlnhourshu, Mlnincomehu, Mlnhourswi, Mlnincomewi, Mwifesharehour, Mwifeshareinc, MlnTOThours, MlnTOTearn
	matrix colnames wild = Mlnhourshu Mlnincomehu Mlnhourswi Mlnincomewi Mwifesharehour Mwifeshareinc MlnTOThours MlnTOTearn
	matrix rownames wild = t_fed p_fed CI_low_fed CI_high_fed t_eg p_eg CI_low_eg CI_high_eg b_sum F_sum P_sum t_sum_WB p_sum_WB F_sum_WB


	matrix Test = ( Blnhourshu ,Blnincomehu ,Blnhourswi ,Blnincomewi ,Bwifesharehour,Bwifeshareinc,BlnTOThours ,BlnTOTearn \ /*
	*/              Flnhourshu ,Flnincomehu ,Flnhourswi ,Flnincomewi ,Fwifesharehour,Fwifeshareinc,FlnTOThours, FlnTOTearn   \ /*
	*/              Plnhourshu ,Plnincomehu ,Plnhourswi ,Plnincomewi ,Pwifesharehour,Pwifeshareinc,PlnTOThours, PlnTOTearn )
	
	matrix colnames Test = lnhourshu lnincomehu lnhourswi lnincomewi wifesharehourwifeshareinc lnTOThours lnTOTearn
	matrix rownames Test = sum F P
	
	matrix E =  Elnhourshu \ Elnincomehu \ Elnhourswi \ Elnincomewi \ Ewifesharehour \ Ewifeshareinc \ ElnTOThours \ ElnTOTearn
	matrix rownames  E = A_lnhourshu  M_lnhourshu A_lnincomehu  M_lnincomehu  A_lnhourswi M_lnhourswi A_lnincomewi M_lnincomewi A_wifesharehour M_wifesharehour A_wifeshareinc M_wifeshareinc A_lnTOThours M_lnTOThours A_lnTOTearn M_lnTOTearn

	log using "$results\tab7_couples `{'`name_subsample'`}' - cluster = `{'`cluster'`}'", append text
	estimates table Clnhourshu Clnincomehu Clnhourswi Clnincomewi Cwifesharehour  Cwifeshareinc ClnTOThours  ClnTOTearn , keep("$treatment_cilw ") b(%9.3f) se(%9.3f) p(%9.3f) stats(N r2 N_full num_singletons df_a_nested) title("Sample = `{'`name_subsample'`}', couple")
	matrix list Test
	matrix list wild
	di "Matrix of EDF"
	matrix list E
	
log close  _all

end


*** RUN PROGRAM
set more off
local date = c(current_date)
res_couples_tab7 "(cohab==1) & duree_couple <=10 & allage == 1 & miss_outcome == 0  & migrant_prov_fam ==0"  "DEF 1 premiere obs - couples AVEC QC" "`date'" "pvreg25"
*=> was renames tab7_couple_0
res_couples_tab7 "(cohab==1) & duree_couple <=10 & allage == 1 & Type_LH_inc4 == 1 &  miss_outcome == 0  & migrant_prov_fam ==0"  "DEF 1 premiere obs -couples women earn less 40 AVEC QC" "`date'" "pvreg25"
*=> was renames tab7_couple_1
res_couples_tab7 "(cohab==1) & duree_couple <=10 & allage == 1 & Type_HL_inc4 == 1 & miss_outcome == 0  & migrant_prov_fam ==0"  "DEF 1 premiere obs -couples women earn more 40 AVEC QC" "`date'" "pvreg25"
*=> was renames tab7_couple_2











exit




