
use BDDPanel2, clear
drop if familyidnum == .
xtset familyidnum year

gen misswi_outcome  = missing(hourswi,incomewi)
gen misshu_outcome  = missing(hourshu,incomehu)


global samplehu "(statehu==2) & allagehu  & duree_couplehu <= 10  & migrant_prov_fam ==0  & misshu_outcome == 0"
global samplewi "(statewi==2) & allagewi  & duree_couplewi <= 10  & migrant_prov_fam ==0  & misswi_outcome == 0"


global spe2wi "has_childwi d_1y_wi-d_10y_wi  y_1994-y_2011  d_1y_c_wi-d_10y_c_wi  y_1994_c_wi-y_2011_c_wi  prov_TN_child_wi-prov_CB_child_wi "
global spe2hu "has_childhu d_1y_hu-d_10y_hu  y_1994-y_2011  d_1y_c_hu-d_10y_c_hu  y_1994_c_hu-y_2011_c_hu  prov_TN_child_hu-prov_CB_child_hu"


global clushu "pvreg25hu"
global cluswi "pvreg25wi"
global clus "pvreg25"


foreach q in "hu" "wi"{
gen after_reffed`q' = 0
replace after_reffed`q' = 1 if year >= year_reffed`q'
gen after_refeg`q' = 0
replace after_refeg`q' = 1 if year >= year_refeg`q'
}


*** For CSDID: we need a variable indicating the year an individual start being treated
****** first year of treatment = year of reform for couples 'caught'
****** first year of treatment = year when couple reach threshold for couples 'non-caught'
****** depends whether the couple has a child or not

foreach q in "wi" "hu"{

	recode year_refeg`q' (.=0)

	* alimony, no children
	gen year_treat_fed`q' = .
	replace year_treat_fed`q' =  year_reffed`q' if couple_fed`q'_bef1 == 1
	replace year_treat_fed`q' =  year_formcouple_`q'+durmin`q'  if couple_fed`q'_noncaught == 1

	* alimony with children
	gen year_treat_fedchild`q' = year_formcouple_`q'+durmin_child`q'   if couple_fed`q'_noncaught == 1 
	gen elig_fedchild_`q' = (year_treat_fedchild`q' < year_treat_fed`q' & year_treat_fed`q' > year & year_treat_fedchild`q' <= year  & has_child`q' == 1)
	bys familyidnum : egen test = sum(elig_fedchild_`q') 
	gen year_elig_fedchild_`q' = year if elig_fedchild_`q' == 1 
	bys familyidnum : egen year_elig_fedchild_`q'2 = min(year_elig_fedchild_`q') 

	replace year_treat_fed`q' = year_elig_fedchild_`q'2 if year_elig_fedchild_`q'2 != .
	drop elig_fedchild_`q' test year_elig_fedchild_`q' year_elig_fedchild_`q'2 

	recode year_treat_fed`q' (. = 0) 

	* marriage like, no children
	gen year_treat_eg`q' = .
	replace year_treat_eg`q' =  year_refeg`q' if couple_eg`q'_bef1 == 1
	replace year_treat_eg`q' =  year_formcouple_`q'+durmin`q'  if couple_eg`q'_noncaught == 1
	recode year_treat_eg`q' (. = 0) 

	* marriage like, with children
	gen year_treat_egchild`q' = year_formcouple_`q'+durmin_child`q'   if couple_eg`q'_noncaught == 1 
	gen elig_egchild_`q' = (year_treat_egchild`q' < year_treat_eg`q' & year_treat_eg`q' > year & year_treat_egchild`q' <= year  & has_child`q' == 1)
	bys familyidnum : egen test2 = sum(elig_egchild_`q') 
	gen year_elig_egchild_`q' = year if elig_egchild_`q' == 1 
	bys familyidnum : egen year_elig_egchild_`q'2 = min(year_elig_egchild_`q') 

	replace year_treat_eg`q' = year_elig_egchild_`q'2 if year_elig_egchild_`q'2 != .
	drop elig_egchild_`q' test2 year_elig_egchild_`q' year_elig_egchild_`q'2 

}


**** Variables for classic event study (command eventdd)

* time to reforms
foreach q in  "wi" "hu"{
gen timeToTreat_reffed`q' = year - year_reffed`q'
gen timeToTreat_refeg`q' = year - year_refeg`q'
}

* time to treatment
foreach q in  "wi" "hu"{
gen timeToTreat_eligfed`q' = year - year_treat_fed`q'
replace timeToTreat_eligfed`q' = . if  duree_couple`q' >10
replace timeToTreat_eligfed`q' = . if year_treat_fed`q' == 0
gen timeToTreat_eligeg`q' = year - year_treat_eg`q'
replace timeToTreat_eligeg`q' = . if  duree_couple`q' >10
replace timeToTreat_eligeg`q' = . if  inlist(pvreg25`q',46,47) == 0
}



foreach q in "wi" "hu"{
gen timeToTreat_fed`q' = .
replace timeToTreat_fed`q' = timeToTreat_reffed`q' if couple_fed`q'_bef1 == 1
replace timeToTreat_fed`q' = timeToTreat_eligfed`q' if couple_fed`q'_noncaught == 1
gen timeToTreat_eg`q' = .
replace timeToTreat_eg`q' = timeToTreat_refeg`q' if couple_eg`q'_bef1 == 1
replace timeToTreat_eg`q' = timeToTreat_eligeg`q' if couple_eg`q'_noncaught == 1
replace timeToTreat_eg`q' = . if timeToTreat_eg`q' > 8
}


* check whether variables are consistent
gen reg_cilwwi2 = (timeToTreat_fedwi>=0 & timeToTreat_fedwi!=.)
gen reg_cilwhu2 = (timeToTreat_fedhu>=0 & timeToTreat_fedhu!=.)



e

********************************************************************************************************
*** STRUCTURE OF THE DOFILE 

*** Forenote: we first count the number of switchers and we restrict analysis to coefficients estimated with at least 20 switchers. 


*** 1/ WOMEN: IMPACT OF ELIGIBLITY 
******* 1.a/ dynamic estimation of coefficients in table 4, panel B
************** 1.a.1/ dynamic impact of alimony eligibility, for non caught couples = restrict sample to couples in Quebec, non caught couples in all alimony provinces, and non caught couples in Mani and Sask before marriage like reform
************** 				=> estimation: event study, DCDH, CS 
************** 1.a.2/ dynamic impact of marriage like eligibility, for caught couples = restrict sample to couples in Quebec, alimony non caught couples in all alimony provinces, and marriage like caught couples in Mani and Sask formed before marriage like
************** 				=> estimation: event study, DCDH, CS 
************** 1.a.3/ dynamic impact of marriage like eligibility, for non caught couples = restrict sample to couples in Quebec, and marriage like caught couples in Mani and Sask 
************** 				=> estimation: event study eligibility, DCDH, CS 
************** => results are in log file: tab5_women_did
******* 1.b/ dynamic estimation of coefficients in table 4, panel A
************** 1.b.1/ dynamic impact of alimony eligibility
************** 				=> estimation: event study, DCDH, CS 
************** 1.b.2/ dynamic impact of marriage like  eligibility
************** 				=> estimation: event study, DCDH, CS 
************** => results are in log file: tab4_women_did

*** 2/ MEN: IMPACT OF ELIGIBLITY  
************** same as for women, results in log files tab5_men_did and tab4_men_did

*** 3/ WOMEN: IMPACT OF REFORM 
************** 	dynamic estimation of coefficients	in table 3	=> estimation: event study, DCDH, CS 
************** => results are in log file: tab1_women_did

*** 4/ MEN: IMPACT OF REFORM 
************** 	dynamic estimation of coefficients	in table 3	=> estimation: event study, DCDH, CS 
************** => results are in log file: tab1_men_did

** diagnotics with twowayfeweights => we were not allowed to show the output

********************************************************************************************************


log using "$results\tab5_women_did", replace text

foreach v of varlist hourswi  lnhourswi lnincomewi notemployedwi noearningswi{

di "*****************************************************************"
di "******************* WOMEN ***************************************"
di "*****************************************************************"

di "*****************************************************************"
di "**** VARIABLE = `v' *****"
di "*****************************************************************"

di "*****************************************************************"
di "***** ALIMONY NON-CAUGHT ****************************************"
di "*****************************************************************"

preserve 

keep if $samplewi & ((pvreg25wi == 24) | (inlist(pvreg25wi, 24,46,47) == 0 & couple_fedwi_noncaught == 1) | (inlist(pvreg25wi,46,47) & couple_fedwi_noncaught == 1 & couple_egwi_bef1 == 1 & regeg_cilwwi==0))

* count switcher and restrict analysis to coefficients estimated with at least 20 switchers. 
did_multiplegt `v' familyidnum year reg_cilwwi , controls($spe2wi) cluster(pvreg25wi) robust_dynamic dynamic(4) placebo(2) longdiff_placebo
	ereturn list
	if e(N_switchers_placebo_2) >= 20 & e(N_switchers_placebo_2) != .{
		local p = 2 
	}
	else{
		local p = 1 
	}
	if e(N_switchers_effect_4) >= 20 & e(N_switchers_effect_4) != .{
		local d = 4 
	}
	else if e(N_switchers_effect_3) >= 20{
		local d = 3
	}
	else if e(N_switchers_effect_2) >= 20{
		local d = 2
	}
	else{
		local d = 1
	}	

di "ESTIM REGHDFE"
qui reghdfe `v' reg_cilwwi regeg_cilwwi $spe2wi $weightwi if $samplewi,  absorb(familyidnum)  vce(cluster $cluswi)
est store reg1
estimates table reg1, keep(reg_cilwwi) b(%9.3f) se(%9.3f) p(%9.3f) stats(N r2 N_full num_singletons df_a_nested) title("`v'")

di "**** ESTIM EVENT STUDY *****"
qui eventdd `v' $spe2wi  $weightwi, hdfe absorb(familyidnum) timevar(timeToTreat_fedwi) ci(rcap) lags(`p') leads(`d') inrange noline
est store es1
local i = 1
global lead "lead0"
while `i'<=`d'{
global lead $lead lead`i'
local i = `i' + 1
}
if `p' == 2{
global lag "lag2 lag3"
}
else{
global lag "lag2"
}
estimates table es1, keep($lag $lead) b(%9.3f) se(%9.3f) p(%9.3f) stats(N r2 N_full num_singletons df_a_nested) title("`v'")


di "**** ESTIM d'HAULTEFOEUILLE de CHAISEMARTIN *****"
did_multiplegt `v' familyidnum year reg_cilwwi2, breps(50) controls($spe2wi) cluster(pvreg25wi) weight(poids_couplewi) robust_dynamic dynamic(`d') placebo(`p') longdiff_placebo

di "**** ESTIM CALLAWAY SANT'ANNA *****"
qui csdid `v' $spe2wi [iw=poids_couplewi], ivar(familyidnum) time(year) gvar(year_treat_fedwi) notyet long2 method(reg) cluster($cluswi) wboot(reps(1999)) saverif(_rif_) replace

restore

preserve
    use _rif_, clear
	di "TESTS USING STANDARD CRVE"
	csdid_stats event, window(-`p' `d')
	di "SAME TESTS USING WILD BOOTSTRAP"
    csdid_stats event, window(-`p' `d') wboot(reps(1999))
restore




di "*****************************************************************"
di "***** MARRIAGE LIKE CAUGHT"
di "*****************************************************************"

preserve 
keep if $samplewi & ((pvreg25wi == 24) | (inlist(pvreg25wi, 24,46,47) == 0 & reg_cilwwi==1 & couple_fedwi_noncaught == 1) | (inlist(pvreg25wi,46,47) & couple_egwi_bef1 == 1 & reg_cilwwi==1 & couple_fedwi_noncaught == 1 ))

did_multiplegt `v' familyidnum year regeg_cilwwi , controls($spe2wi) cluster(pvreg25wi) robust_dynamic dynamic(4) placebo(2) longdiff_placebo
	ereturn list
	if e(N_switchers_placebo_2) >= 20 & e(N_switchers_placebo_2) != .{
		local p = 2 
	}
	else{
		local p = 1 
	}
	if e(N_switchers_effect_4) >= 20 & e(N_switchers_effect_4) != .{
		local d = 4 
	}
	else if e(N_switchers_effect_3) >= 20{
		local d = 3
	}
	else if e(N_switchers_effect_2) >= 20{
		local d = 2
	}
	else{
		local d = 1
	}	

di "ESTIM REGHDFE"
qui reghdfe `v' reg_cilwwi regeg_cilwwi $spe2wi $weightwi if $samplewi,  absorb(familyidnum)  vce(cluster $cluswi)
est store reg1
estimates table reg1, keep(reg_cilwwi regeg_cilwwi) b(%9.3f) se(%9.3f) p(%9.3f) stats(N r2 N_full num_singletons df_a_nested) title("`v'")

di "**** ESTIM EVENT STUDY *****"
qui eventdd `v' $spe2wi reg_cilwwi  $weightwi, hdfe absorb(familyidnum) timevar(timeToTreat_egwi) ci(rcap) lags(`p') leads(`d') inrange noline
est store es1
local i = 1
global lead "lead0"
while `i'<=`d'{
global lead $lead lead`i'
local i = `i' + 1
}
if `p' == 2{
global lag "lag2 lag3"
}
else{
global lag "lag2"
}
estimates table es1, keep(reg_cilwwi $lag $lead) b(%9.3f) se(%9.3f) p(%9.3f) stats(N r2 N_full num_singletons df_a_nested) title("`v'")

di "**** ESTIM d'HAULTEFOEUILLE de CHAISEMARTIN *****"
did_multiplegt `v' familyidnum year regeg_cilwwi, breps(50) controls($spe2wi reg_cilwwi) cluster(pvreg25wi) weight(poids_couplewi) robust_dynamic dynamic(`d') placebo(`p') longdiff_placebo

di "**** ESTIM CALLAWAY SANT'ANNA *****"
qui csdid `v' $spe2wi reg_cilwwi [iw=poids_couplewi], ivar(familyidnum) time(year) gvar(year_treat_egwi) notyet method(reg) long2 cluster($cluswi) wboot(reps(1999)) saverif(_rif_) replace 

restore

preserve
    use _rif_, clear
	di "TESTS USING STANDARD CRVE"
	csdid_stats event, window(-`p' `d')
	di "SAME TESTS USING WILD BOOTSTRAP"
    csdid_stats event, window(-`p' `d') wboot(reps(1999))
restore





di "*****************************************************************"
di "***** MARRIAGE LIKE  NON-CAUGHT"
di "*****************************************************************"

preserve 
keep if $samplewi & ((pvreg25wi == 24) | (inlist(pvreg25wi,46,47) & couple_egwi_noncaught == 1 ))

did_multiplegt `v' familyidnum year regeg_cilwwi , controls($spe2wi) cluster(pvreg25wi) robust_dynamic dynamic(4) placebo(2) longdiff_placebo
	ereturn list
	if e(N_switchers_placebo_2) >= 20 & e(N_switchers_placebo_2) != .{
		local p = 2 
	}
	else{
		local p = 1 
	}
	if e(N_switchers_effect_4) >= 20 & e(N_switchers_effect_4) != .{
		local d = 4 
	}
	else if e(N_switchers_effect_3) >= 20{
		local d = 3
	}
	else if e(N_switchers_effect_2) >= 20{
		local d = 2
	}
	else{
		local d = 1
	}	

di "ESTIM REGHDFE"
qui reghdfe `v' regeg_cilwwi $spe2wi $weightwi,  absorb(familyidnum)  vce(cluster $cluswi)
est store reg1
estimates table reg1, keep(regeg_cilwwi) b(%9.3f) se(%9.3f) p(%9.3f) stats(N r2 N_full num_singletons df_a_nested) title("`v'")

di "**** ESTIM EVENT STUDY *****"
qui eventdd `v' $spe2wi  $weightwi, hdfe absorb(familyidnum) timevar(timeToTreat_egwi) ci(rcap) lags(`p') leads(`d') inrange noline
est store es1
local i = 1
global lead "lead0"
while `i'<=`d'{
global lead $lead lead`i'
local i = `i' + 1
}
if `p' == 2{
global lag "lag2 lag3"
}
else{
global lag "lag2"
}
estimates table es1, keep($lag $lead) b(%9.3f) se(%9.3f) p(%9.3f) stats(N r2 N_full num_singletons df_a_nested) title("`v'")

di "**** ESTIM d'HAULTEFOEUILLE de CHAISEMARTIN *****"
did_multiplegt `v' familyidnum year regeg_cilwwi, breps(50) controls($spe2wi) cluster(pvreg25wi) weight(poids_couplewi) robust_dynamic dynamic(`d') placebo(`p') longdiff_placebo

di "**** ESTIM CALLAWAY SANT'ANNA *****"
qui csdid `v' $spe2wi [iw=poids_couplewi], ivar(familyidnum) time(year) gvar(year_treat_egwi) notyet method(reg) long2 cluster($cluswi) wboot(reps(1999)) saverif(_rif_) replace


restore


preserve
    use _rif_, clear
	di "TESTS USING STANDARD CRVE"
	csdid_stats event, window(-`p' `d')
	di "SAME TESTS USING WILD BOOTSTRAP"
    csdid_stats event, window(-`p' `d') wboot(reps(1999))
restore


}
log close _all


***********  IMPACT OF ELIGIBILITY (CAUGHT AND NON CAUGHT TOGETHER) **************


log using "$results\tab4_women_did", replace text

di "*****************************************************************"
di "******************* WOMEN ***************************************"
di "*****************************************************************"


di "***********  IMPACT OF ELIGIBILITY (CAUGHT AND NON CAUGHT TOGETHER) **************"



foreach v of varlist hourswi  lnhourswi lnincomewi notemployedwi noearningswi{

di "********************************************"
di "***** ALIMONY "
di "*******************************************"

di "*****************************************************************"
di "**** VARIABLE = `v' *****"
di "*****************************************************************"

preserve 

keep if $samplewi 

did_multiplegt `v' familyidnum year reg_cilwwi2 , controls($spe2wi regeg_cilwwi) cluster(pvreg25wi) robust_dynamic dynamic(4) placebo(2) longdiff_placebo
	ereturn list
	if e(N_switchers_placebo_2) >= 20 & e(N_switchers_placebo_2) != .{
		local p = 2 
	}
	else{
		local p = 1 
	}
	if e(N_switchers_effect_4) >= 20 & e(N_switchers_effect_4) != .{
		local d = 4 
	}
	else if e(N_switchers_effect_3) >= 20{
		local d = 3
	}
	else if e(N_switchers_effect_2) >= 20{
		local d = 2
	}
	else{
		local d = 1
	}	


di "**** ESTIM REGHDFE *****"

qui reghdfe `v' reg_cilwwi regeg_cilwwi $spe2wi $weightwi if $samplewi,  absorb(familyidnum)  vce(cluster $cluswi)
est store reg1
estimates table reg1, keep(reg_cilwwi regeg_cilwwi) b(%9.3f) se(%9.3f) p(%9.3f) stats(N r2 N_full num_singletons df_a_nested) title("`v'")

di "**** ESTIM EVENT STUDY *****"
qui eventdd `v' $spe2wi regeg_cilwwi $weightwi, hdfe absorb(familyidnum) timevar(timeToTreat_fedwi) ci(rcap) lags(`p') leads(`d') inrange noline
est store es1
local i = 1
global lead "lead0"
while `i'<=`d'{
global lead $lead lead`i'
local i = `i' + 1
}
if `p' == 2{
global lag "lag3 lag2"
}
else{
global lag "lag2"
}
estimates table es1, keep($lag $lead regeg_cilwwi) b(%9.3f) se(%9.3f) p(%9.3f) stats(N r2 N_full num_singletons df_a_nested) title("`v'")

di "**** ESTIM d'HAULTEFOEUILLE de CHAISEMARTIN *****"
did_multiplegt `v' familyidnum year reg_cilwwi2, breps(50) controls($spe2wi regeg_cilwwi) cluster(pvreg25wi) weight(poids_couplewi) robust_dynamic dynamic(`d') placebo(`p') longdiff_placebo

di "**** ESTIM CALLAWAY SANT'ANNA *****"
qui csdid `v' $spe2wi regeg_cilwwi [iw=poids_couplewi], ivar(familyidnum) time(year) gvar(year_treat_fedwi) notyet method(reg) long2 cluster($cluswi) wboot(reps(1999)) saverif(_rif_) replace

restore

preserve
    use _rif_, clear
	di "TESTS USING STANDARD CRVE"
	csdid_stats event, window(-`p' `d')
	di "SAME TESTS USING WILD BOOTSTRAP"
    csdid_stats event, window(-`p' `d') wboot(reps(1999))
restore



di "*********************************************************"
di "************** MARRIAGE LIKE  ***************************"
di "*********************************************************"


preserve 

keep if $samplewi 

did_multiplegt `v' familyidnum year regeg_cilwwi , controls($spe2wi reg_cilwwi) cluster(pvreg25wi) robust_dynamic dynamic(4) placebo(2) longdiff_placebo
	ereturn list
	if e(N_switchers_placebo_2) >= 20 & e(N_switchers_placebo_2) != .{
		local p = 2 
	}
	else{
		local p = 1 
	}
	if e(N_switchers_effect_4) >= 20 & e(N_switchers_effect_4) != .{
		local d = 4 
	}
	else if e(N_switchers_effect_3) >= 20{
		local d = 3
	}
	else if e(N_switchers_effect_2) >= 20{
		local d = 2
	}
	else{
		local d = 1
	}	

di "ESTIM REGHDFE"
qui reghdfe `v' reg_cilwwi regeg_cilwwi $spe2wi $weightwi if $samplewi,  absorb(familyidnum)  vce(cluster $cluswi)
est store reg1
estimates table reg1, keep(reg_cilwwi regeg_cilwwi) b(%9.3f) se(%9.3f) p(%9.3f) stats(N r2 N_full num_singletons df_a_nested) title("`v'")


di "**** ESTIM EVENT STUDY *****"
qui eventdd `v' $spe2wi reg_cilwwi $weightwi, hdfe absorb(familyidnum) timevar(timeToTreat_egwi) ci(rcap) lags(`p') leads(`d') inrange noline
est store es1
local i = 1
global lead "lead0"
while `i'<=`d'{
global lead $lead lead`i'
local i = `i' + 1
}
if `p' == 2{
global lag "lag3 lag2"
}
else{
global lag "lag2"
}
estimates table es1, keep($lag $lead reg_cilwwi) b(%9.3f) se(%9.3f) p(%9.3f) stats(N r2 N_full num_singletons df_a_nested) title("`v'")


di "**** ESTIM d'HAULTEFOEUILLE de CHAISEMARTIN *****"
did_multiplegt `v' familyidnum year regeg_cilwwi, breps(50) controls($spe2wi reg_cilwwi) cluster(pvreg25wi) weight(poids_couplewi) robust_dynamic dynamic(`d') placebo(`p') longdiff_placebo

di "**** ESTIM CALLAWAY SANT'ANNA *****"
qui csdid `v' $spe2wi reg_cilwwi [iw=poids_couplewi], ivar(familyidnum) time(year) gvar(year_treat_egwi) notyet method(reg) long2 cluster($cluswi) wboot(reps(1999)) saverif(_rif_) replace

restore

preserve
    use _rif_, clear
	di "TESTS USING STANDARD CRVE"
	csdid_stats event, window(-`p' `d')
	di "SAME TESTS USING WILD BOOTSTRAP"
    csdid_stats event, window(-`p' `d') wboot(reps(1999))
restore

}
log close _all



*********************************************************************************************************





log using "$results\tab5_men_did", replace text

foreach v of varlist hourshu  lnhourshu lnincomehu wkactifhu{

di "*****************************************************************"
di "******************* MEN ***************************************"
di "*****************************************************************"

di "*****************************************************************"
di "**** VARIABLE = `v' *****"
di "*****************************************************************"

di "*****************************************************************"
di "***** ALIMONY NON-CAUGHT ****************************************"
di "*****************************************************************"

preserve 

keep if $samplehu & ((pvreg25hu == 24) | (inlist(pvreg25hu, 24,46,47) == 0 & couple_fedhu_noncaught == 1) | (inlist(pvreg25hu,46,47) & couple_fedhu_noncaught == 1 & couple_eghu_bef1 == 1 & regeg_cilwhu==0))

did_multiplegt `v' familyidnum year reg_cilwhu , controls($spe2hu) cluster(pvreg25hu) robust_dynamic dynamic(4) placebo(2) longdiff_placebo
	ereturn list
	if e(N_switchers_placebo_2) >= 20 & e(N_switchers_placebo_2) != .{
		local p = 2 
	}
	else{
		local p = 1 
	}
	if e(N_switchers_effect_4) >= 20 & e(N_switchers_effect_4) != .{
		local d = 4 
	}
	else if e(N_switchers_effect_3) >= 20{
		local d = 3
	}
	else if e(N_switchers_effect_2) >= 20{
		local d = 2
	}
	else{
		local d = 1
	}	

di "ESTIM REGHDFE"
qui reghdfe `v' reg_cilwhu regeg_cilwhu $spe2hu $weighthu if $samplehu,  absorb(familyidnum)  vce(cluster $clushu)
est store reg1
estimates table reg1, keep(reg_cilwhu) b(%9.3f) se(%9.3f) p(%9.3f) stats(N r2 N_full num_singletons df_a_nested) title("`v'")

di "**** ESTIM EVENT STUDY *****"
qui eventdd `v' $spe2hu  $weighthu, hdfe absorb(familyidnum) timevar(timeToTreat_fedhu) ci(rcap) lags(`p') leads(`d') inrange noline
est store es1
local i = 1
global lead "lead0"
while `i'<=`d'{
global lead $lead lead`i'
local i = `i' + 1
}
if `p' == 2{
global lag "lag2 lag3"
}
else{
global lag "lag2"
}
estimates table es1, keep($lag $lead) b(%9.3f) se(%9.3f) p(%9.3f) stats(N r2 N_full num_singletons df_a_nested) title("`v'")


di "**** ESTIM d'HAULTEFOEUILLE de CHAISEMARTIN *****"
did_multiplegt `v' familyidnum year reg_cilwhu2, breps(50) controls($spe2hu) cluster(pvreg25hu) weight(poids_couplehu) robust_dynamic dynamic(`d') placebo(`p') longdiff_placebo

di "**** ESTIM CALLAWAY SANT'ANNA *****"
qui csdid `v' $spe2hu [iw=poids_couplehu], ivar(familyidnum) time(year) gvar(year_treat_fedhu) notyet long2 method(reg) cluster($clushu) wboot(reps(1999)) saverif(_rif_) replace

restore

preserve
    use _rif_, clear
	di "TESTS USING STANDARD CRVE"
	csdid_stats event, window(-`p' `d')
	di "SAME TESTS USING wild BOOTSTRAP"
    csdid_stats event, window(-`p' `d') wboot(reps(1999))
restore




di "*****************************************************************"
di "***** MARRIAGE LIKE CAUGHT"
di "*****************************************************************"

preserve 
keep if $samplehu & ((pvreg25hu == 24) | (inlist(pvreg25hu, 24,46,47) == 0 & reg_cilwhu==1 & couple_fedhu_noncaught == 1) | (inlist(pvreg25hu,46,47) & couple_eghu_bef1 == 1 & reg_cilwhu==1 & couple_fedhu_noncaught == 1 ))

did_multiplegt `v' familyidnum year regeg_cilwhu , controls($spe2hu) cluster(pvreg25hu) robust_dynamic dynamic(4) placebo(2) longdiff_placebo
	ereturn list
	if e(N_switchers_placebo_2) >= 20 & e(N_switchers_placebo_2) != .{
		local p = 2 
	}
	else{
		local p = 1 
	}
	if e(N_switchers_effect_4) >= 20 & e(N_switchers_effect_4) != .{
		local d = 4 
	}
	else if e(N_switchers_effect_3) >= 20{
		local d = 3
	}
	else if e(N_switchers_effect_2) >= 20{
		local d = 2
	}
	else{
		local d = 1
	}	

di "ESTIM REGHDFE"
qui reghdfe `v' reg_cilwhu regeg_cilwhu $spe2hu $weighthu if $samplehu,  absorb(familyidnum)  vce(cluster $clushu)
est store reg1
estimates table reg1, keep(reg_cilwhu regeg_cilwhu) b(%9.3f) se(%9.3f) p(%9.3f) stats(N r2 N_full num_singletons df_a_nested) title("`v'")

di "**** ESTIM EVENT STUDY *****"
qui eventdd `v' $spe2hu reg_cilwhu  $weighthu, hdfe absorb(familyidnum) timevar(timeToTreat_eghu) ci(rcap) lags(`p') leads(`d') inrange noline
est store es1
local i = 1
global lead "lead0"
while `i'<=`d'{
global lead $lead lead`i'
local i = `i' + 1
}
if `p' == 2{
global lag "lag2 lag3"
}
else{
global lag "lag2"
}
estimates table es1, keep(reg_cilwhu $lag $lead) b(%9.3f) se(%9.3f) p(%9.3f) stats(N r2 N_full num_singletons df_a_nested) title("`v'")

di "**** ESTIM d'HAULTEFOEUILLE de CHAISEMARTIN *****"
did_multiplegt `v' familyidnum year regeg_cilwhu, breps(50) controls($spe2hu reg_cilwhu) cluster(pvreg25hu) weight(poids_couplehu) robust_dynamic dynamic(`d') placebo(`p') longdiff_placebo

di "**** ESTIM CALLAWAY SANT'ANNA *****"
qui csdid `v' $spe2hu reg_cilwhu [iw=poids_couplehu], ivar(familyidnum) time(year) gvar(year_treat_eghu) notyet method(reg) long2 cluster($clushu) wboot(reps(1999)) saverif(_rif_) replace 

restore

preserve
    use _rif_, clear
	di "TESTS USING STANDARD CRVE"
	csdid_stats event, window(-`p' `d')
	di "SAME TESTS USING wild BOOTSTRAP"
    csdid_stats event, window(-`p' `d') wboot(reps(1999))
restore





di "*****************************************************************"
di "***** MARRIAGE LIKE  NON-CAUGHT"
di "*****************************************************************"

preserve 
keep if $samplehu & ((pvreg25hu == 24) | (inlist(pvreg25hu,46,47) & couple_eghu_noncaught == 1 ))

did_multiplegt `v' familyidnum year regeg_cilwhu , controls($spe2hu) cluster(pvreg25hu) robust_dynamic dynamic(4) placebo(2) longdiff_placebo
	ereturn list
	if e(N_switchers_placebo_2) >= 20 & e(N_switchers_placebo_2) != .{
		local p = 2 
	}
	else{
		local p = 1 
	}
	if e(N_switchers_effect_4) >= 20 & e(N_switchers_effect_4) != .{
		local d = 4 
	}
	else if e(N_switchers_effect_3) >= 20{
		local d = 3
	}
	else if e(N_switchers_effect_2) >= 20{
		local d = 2
	}
	else{
		local d = 1
	}	

di "ESTIM REGHDFE"
qui reghdfe `v' regeg_cilwhu $spe2hu $weighthu,  absorb(familyidnum)  vce(cluster $clushu)
est store reg1
estimates table reg1, keep(regeg_cilwhu) b(%9.3f) se(%9.3f) p(%9.3f) stats(N r2 N_full num_singletons df_a_nested) title("`v'")

di "**** ESTIM EVENT STUDY *****"
qui eventdd `v' $spe2hu  $weighthu, hdfe absorb(familyidnum) timevar(timeToTreat_eghu) ci(rcap) lags(`p') leads(`d') inrange noline
est store es1
local i = 1
global lead "lead0"
while `i'<=`d'{
global lead $lead lead`i'
local i = `i' + 1
}
if `p' == 2{
global lag "lag2 lag3"
}
else{
global lag "lag2"
}
estimates table es1, keep($lag $lead) b(%9.3f) se(%9.3f) p(%9.3f) stats(N r2 N_full num_singletons df_a_nested) title("`v'")

di "**** ESTIM d'HAULTEFOEUILLE de CHAISEMARTIN *****"
did_multiplegt `v' familyidnum year regeg_cilwhu, breps(50) controls($spe2hu) cluster(pvreg25hu) weight(poids_couplehu) robust_dynamic dynamic(`d') placebo(`p') longdiff_placebo

di "**** ESTIM CALLAWAY SANT'ANNA *****"
qui csdid `v' $spe2hu [iw=poids_couplehu], ivar(familyidnum) time(year) gvar(year_treat_eghu) notyet method(reg) long2 cluster($clushu) wboot(reps(1999)) saverif(_rif_) replace


restore


preserve
    use _rif_, clear
	di "TESTS USING STANDARD CRVE"
	csdid_stats event, window(-`p' `d')
	di "SAME TESTS USING wild BOOTSTRAP"
    csdid_stats event, window(-`p' `d') wboot(reps(1999))
restore


}
log close _all


***********  IMPACT OF ELIGIBILITY (CAUGHT AND NON CAUGHT TOGETHER) **************


log using "$results\tab4_men_did", replace text

di "*****************************************************************"
di "******************* MEN ***************************************"
di "*****************************************************************"


di "***********  IMPACT OF ELIGIBILITY (CAUGHT AND NON CAUGHT TOGETHER) **************"



foreach v of varlist hourshu  lnhourshu lnincomehu wkactifhu{

di "********************************************"
di "***** ALIMONY "
di "*******************************************"

di "*****************************************************************"
di "**** VARIABLE = `v' *****"
di "*****************************************************************"

preserve 

keep if $samplehu 

did_multiplegt `v' familyidnum year reg_cilwhu2 , controls($spe2hu regeg_cilwhu) cluster(pvreg25hu) robust_dynamic dynamic(4) placebo(2) longdiff_placebo
	ereturn list
	if e(N_switchers_placebo_2) >= 20 & e(N_switchers_placebo_2) != .{
		local p = 2 
	}
	else{
		local p = 1 
	}
	if e(N_switchers_effect_4) >= 20 & e(N_switchers_effect_4) != .{
		local d = 4 
	}
	else if e(N_switchers_effect_3) >= 20{
		local d = 3
	}
	else if e(N_switchers_effect_2) >= 20{
		local d = 2
	}
	else{
		local d = 1
	}	


di "**** ESTIM REGHDFE *****"

qui reghdfe `v' reg_cilwhu regeg_cilwhu $spe2hu $weighthu if $samplehu,  absorb(familyidnum)  vce(cluster $clushu)
est store reg1
estimates table reg1, keep(reg_cilwhu regeg_cilwhu) b(%9.3f) se(%9.3f) p(%9.3f) stats(N r2 N_full num_singletons df_a_nested) title("`v'")

di "**** ESTIM EVENT STUDY *****"
qui eventdd `v' $spe2hu regeg_cilwhu $weighthu, hdfe absorb(familyidnum) timevar(timeToTreat_fedhu) ci(rcap) lags(`p') leads(`d') inrange noline
est store es1
local i = 1
global lead "lead0"
while `i'<=`d'{
global lead $lead lead`i'
local i = `i' + 1
}
if `p' == 2{
global lag "lag3 lag2"
}
else{
global lag "lag2"
}
estimates table es1, keep($lag $lead regeg_cilwhu) b(%9.3f) se(%9.3f) p(%9.3f) stats(N r2 N_full num_singletons df_a_nested) title("`v'")

di "**** ESTIM d'HAULTEFOEUILLE de CHAISEMARTIN *****"
did_multiplegt `v' familyidnum year reg_cilwhu2, breps(50) controls($spe2hu regeg_cilwhu) cluster(pvreg25hu) weight(poids_couplehu) robust_dynamic dynamic(`d') placebo(`p') longdiff_placebo

di "**** ESTIM CALLAWAY SANT'ANNA *****"
qui csdid `v' $spe2hu regeg_cilwhu [iw=poids_couplehu], ivar(familyidnum) time(year) gvar(year_treat_fedhu) notyet method(reg) long2 cluster($clushu) wboot(reps(1999)) saverif(_rif_) replace

restore

preserve
    use _rif_, clear
	di "TESTS USING STANDARD CRVE"
	csdid_stats event, window(-`p' `d')
	di "SAME TESTS USING wild BOOTSTRAP"
    csdid_stats event, window(-`p' `d') wboot(reps(1999))
restore



di "*********************************************************"
di "************** MARRIAGE LIKE  ***************************"
di "*********************************************************"


preserve 

keep if $samplehu 

did_multiplegt `v' familyidnum year regeg_cilwhu , controls($spe2hu reg_cilwhu) cluster(pvreg25hu) robust_dynamic dynamic(4) placebo(2) longdiff_placebo
	ereturn list
	if e(N_switchers_placebo_2) >= 20 & e(N_switchers_placebo_2) != .{
		local p = 2 
	}
	else{
		local p = 1 
	}
	if e(N_switchers_effect_4) >= 20 & e(N_switchers_effect_4) != .{
		local d = 4 
	}
	else if e(N_switchers_effect_3) >= 20{
		local d = 3
	}
	else if e(N_switchers_effect_2) >= 20{
		local d = 2
	}
	else{
		local d = 1
	}	

di "ESTIM REGHDFE"
qui reghdfe `v' reg_cilwhu regeg_cilwhu $spe2hu $weighthu if $samplehu,  absorb(familyidnum)  vce(cluster $clushu)
est store reg1
estimates table reg1, keep(reg_cilwhu regeg_cilwhu) b(%9.3f) se(%9.3f) p(%9.3f) stats(N r2 N_full num_singletons df_a_nested) title("`v'")


di "**** ESTIM EVENT STUDY *****"
qui eventdd `v' $spe2hu reg_cilwhu $weighthu, hdfe absorb(familyidnum) timevar(timeToTreat_eghu) ci(rcap) lags(`p') leads(`d') inrange noline
est store es1
local i = 1
global lead "lead0"
while `i'<=`d'{
global lead $lead lead`i'
local i = `i' + 1
}
if `p' == 2{
global lag "lag3 lag2"
}
else{
global lag "lag2"
}
estimates table es1, keep($lag $lead reg_cilwhu) b(%9.3f) se(%9.3f) p(%9.3f) stats(N r2 N_full num_singletons df_a_nested) title("`v'")


di "**** ESTIM d'HAULTEFOEUILLE de CHAISEMARTIN *****"
did_multiplegt `v' familyidnum year regeg_cilwhu, breps(50) controls($spe2hu reg_cilwhu) cluster(pvreg25hu) weight(poids_couplehu) robust_dynamic dynamic(`d') placebo(`p') longdiff_placebo

di "**** ESTIM CALLAWAY SANT'ANNA *****"
qui csdid `v' $spe2hu reg_cilwhu [iw=poids_couplehu], ivar(familyidnum) time(year) gvar(year_treat_eghu) notyet method(reg) long2 cluster($clushu) wboot(reps(1999)) saverif(_rif_) replace

restore

preserve
    use _rif_, clear
	di "TESTS USING STANDARD CRVE"
	csdid_stats event, window(-`p' `d')
	di "SAME TESTS USING WILD BOOTSTRAP"
    csdid_stats event, window(-`p' `d') wboot(reps(1999))
restore

}
log close _all


***************************************************************************************


*****************************************************************"
***********  IMPACT OF REFORM (MARRIAGE LIKE ONLY) *************
*****************************************************************"

cap log close _all
log using "$results\tab1_women_did", replace text

di "*****************************************************************"
di "******************* WOMEN ***************************************"
di "*****************************************************************"


di "***********  IMPACT OF REFORM (MARRIAGE LIKE ONLY) *************"

foreach v of varlist hourswi lnhourswi lnincomewi notemployedwi noearningswi{

di "*****************************************************************"
di "**** VARIABLE = `v' *****"
di "*****************************************************************"



preserve 

keep if $samplewi 

did_multiplegt `v' familyidnum year reform_egalwi , controls($spe2wi reform_fedwi) cluster(pvreg25wi) robust_dynamic dynamic(4) placebo(2) longdiff_placebo
	ereturn list
	if e(N_switchers_placebo_2) >= 20 & e(N_switchers_placebo_2) != .{
		local p = 2 
	}
	else{
		local p = 1 
	}
	if e(N_switchers_effect_4) >= 20 & e(N_switchers_effect_4) != .{
		local d = 4 
	}
	else if e(N_switchers_effect_3) >= 20{
		local d = 3
	}
	else if e(N_switchers_effect_2) >= 20{
		local d = 2
	}
	else{
		local d = 1
	}	
di "p=`p'"
di "d=`d'"
di "ESTIM REGHDFE"
qui reghdfe `v' reform_fedwi reform_egalwi $spe2wi $weightwi if $samplewi,  absorb(familyidnum)  vce(cluster $cluswi)
est store reg1
estimates table reg1, keep(reform_fedwi reform_egalwi) b(%9.3f) se(%9.3f) p(%9.3f) stats(N r2 N_full num_singletons df_a_nested) title("`v'")


di "**** ESTIM EVENT STUDY *****"
replace timeToTreat_refegwi = . if timeToTreat_refegwi > 14
qui eventdd `v' after_reffedwi $spe2wi  $weightwi, hdfe absorb(familyidnum) timevar(timeToTreat_refegwi) ci(rcap) lags(`p') leads(`d') inrange noline
est store es1
local i = 1
global lead "lead0"
while `i'<=`d'{
global lead $lead lead`i'
local i = `i' + 1
}
if `p' == 2{
global lag "lag3 lag2"
}
else{
global lag "lag2"
}
estimates table es1, keep($lag $lead after_reffedwi) b(%9.3f) se(%9.3f) p(%9.3f) stats(N r2 N_full num_singletons df_a_nested) title("`v'")


di "**** ESTIM d'HAULTEFOEUILLE de CHAISEMARTIN *****"
did_multiplegt `v' familyidnum year after_refegwi, breps(50) controls($spe2wi after_reffedwi) cluster(pvreg25wi) weight(poids_couplewi) robust_dynamic dynamic(`d') placebo(`p') longdiff_placebo

di "**** ESTIM CALLAWAY SANT'ANNA *****"
qui csdid `v' $spe2wi after_reffedwi [iw=poids_couplewi], ivar(familyidnum) time(year) gvar(year_treat_egwi) notyet method(reg) long2 cluster($cluswi) wboot(reps(999)) saverif(_rif_) replace


restore

preserve
    use _rif_, clear
	di "TESTS USING STANDARD CRVE"
	csdid_stats event, window(-`p' `d')
	di "SAME TESTS USING WILD BOOTSTRAP"
    csdid_stats event, window(-`p' `d') wboot(reps(999))
restore

}

log close _all






*****************************************************************
***********  IMPACT OF REFORM (MARRIAGE LIKE ONLY) *************
*****************************************************************

cap log close _all
log using "$results\tab1_men_did", replace text

di "*****************************************************************"
di "******************* MEN ***************************************"
di "*****************************************************************"


di "***********  IMPACT OF REFORM (MARRIAGE LIKE ONLY) *************"

foreach v of varlist hourshu lnhourshu lnincomehu wkactifhu{

di "*****************************************************************"
di "**** VARIABLE = `v' *****"
di "*****************************************************************"



preserve 

keep if $samplehu 

did_multiplegt `v' familyidnum year reform_egalhu , controls($spe2hu reform_fedhu) cluster(pvreg25hu) robust_dynamic dynamic(4) placebo(2) longdiff_placebo
	ereturn list
	if e(N_switchers_placebo_2) >= 20 & e(N_switchers_placebo_2) != .{
		local p = 2 
	}
	else{
		local p = 1 
	}
	if e(N_switchers_effect_4) >= 20 & e(N_switchers_effect_4) != .{
		local d = 4 
	}
	else if e(N_switchers_effect_3) >= 20{
		local d = 3
	}
	else if e(N_switchers_effect_2) >= 20{
		local d = 2
	}
	else{
		local d = 1
	}	
di "p=`p'"
di "d=`d'"
di "ESTIM REGHDFE"
qui reghdfe `v' reform_fedhu reform_egalhu $spe2hu $weighthu if $samplehu,  absorb(familyidnum)  vce(cluster $clushu)
est store reg1
estimates table reg1, keep(reform_fedhu reform_egalhu) b(%9.3f) se(%9.3f) p(%9.3f) stats(N r2 N_full num_singletons df_a_nested) title("`v'")


di "**** ESTIM EVENT STUDY *****"
replace timeToTreat_refeghu = . if timeToTreat_refeghu > 14
qui eventdd `v' after_reffedhu $spe2hu  $weighthu, hdfe absorb(familyidnum) timevar(timeToTreat_refeghu) ci(rcap) lags(`p') leads(`d') inrange noline
est store es1
local i = 1
global lead "lead0"
while `i'<=`d'{
global lead $lead lead`i'
local i = `i' + 1
}
if `p' == 2{
global lag "lag3 lag2"
}
else{
global lag "lag2"
}
estimates table es1, keep($lag $lead after_reffedhu) b(%9.3f) se(%9.3f) p(%9.3f) stats(N r2 N_full num_singletons df_a_nested) title("`v'")


di "**** ESTIM d'HAULTEFOEUILLE de CHAISEMARTIN *****"
did_multiplegt `v' familyidnum year after_refeghu, breps(50) controls($spe2hu after_reffedhu) cluster(pvreg25hu) weight(poids_couplehu) robust_dynamic dynamic(`d') placebo(`p') longdiff_placebo

di "**** ESTIM CALLAWAY SANT'ANNA *****"
qui csdid `v' $spe2hu after_reffedhu [iw=poids_couplehu], ivar(familyidnum) time(year) gvar(year_treat_eghu) notyet method(reg) long2 cluster($clushu) wboot(reps(999)) saverif(_rif_) replace


restore

preserve
    use _rif_, clear
	di "TESTS USING STANDARD CRVE"
	csdid_stats event, window(-`p' `d')
	di "SAME TESTS USING WILD BOOTSTRAP"
    csdid_stats event, window(-`p' `d') wboot(reps(999))
restore

}

log close _all




